==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/General/copypaste/translations/copypaste_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl_NL">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="47"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="48"/>
        <source>Ctrl+V</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="28"/>
        <source>Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="48"/>
        <source>About Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>This plugin allows to copy selected tracks from one playlist to another</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/copypaste/translations/copypaste_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl_NL">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="47"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="48"/>
        <source>Ctrl+V</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="30"/>
        <source>Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>About Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="52"/>
        <source>This plugin allows one to copy selected tracks from one playlist to another</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
